import { Request, Response } from "express";
import ExecutivePositionService from "../../service/executivePositionService";
import ExecutivePositionFactory from "../../factory/admin/executivePosition";

/**
 * @description get all executivePositions
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function getAllExecutivePositions(req: Request, res: Response): Promise<any> {
  let positions = await ExecutivePositionService.getAll();

  res.json(ExecutivePositionFactory.mapToBase(positions));
}

/**
 * @description get executivePosition by id
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function getExecutivePositionById(req: Request, res: Response): Promise<any> {
  const id = parseInt(req.params.id);
  let position = await ExecutivePositionService.getById(id);

  res.json(ExecutivePositionFactory.mapToSingle(position));
}

/**
 * @description get members assigned to executivePosition by id
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function getExecutivePositionAssignedMembers(req: Request, res: Response): Promise<any> {
  const executivePositionId = parseInt(req.params.id);

  res.json([]);
}

/**
 * @description create new executivePosition
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function createExecutivePosition(req: Request, res: Response): Promise<any> {
  const executivePosition = req.body.executivePosition;

  res.sendStatus(204);
}

/**
 * @description update executivePosition
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function updateExecutivePosition(req: Request, res: Response): Promise<any> {
  const id = parseInt(req.params.id);
  const executivePosition = req.body.executivePosition;

  res.sendStatus(204);
}

/**
 * @description delete executivePosition
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function deleteExecutivePosition(req: Request, res: Response): Promise<any> {
  const id = parseInt(req.params.id);

  res.sendStatus(204);
}
