import { Request, Response } from "express";
import QualificationService from "../../service/qualification";
import QualificationFactory from "../../factory/admin/qualification";

/**
 * @description get all qualifications
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function getAllQualifications(req: Request, res: Response): Promise<any> {
  let qualifications = await QualificationService.getAll();

  res.json(QualificationFactory.mapToBase(qualifications));
}

/**
 * @description get qualification by id
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function getQualificationById(req: Request, res: Response): Promise<any> {
  const id = parseInt(req.params.id);
  let qualification = await QualificationService.getById(id);

  res.json(QualificationFactory.mapToSingle(qualification));
}

/**
 * @description get members assigned to qualification by id
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function getQualificationAssignedMembers(req: Request, res: Response): Promise<any> {
  const qualificationId = parseInt(req.params.id);

  res.json({});
}

/**
 * @description create new qualification
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function createQualification(req: Request, res: Response): Promise<any> {
  const qualification = req.body.qualification;

  res.sendStatus(204);
}

/**
 * @description update qualification
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function updateQualification(req: Request, res: Response): Promise<any> {
  const id = parseInt(req.params.id);
  const qualification = req.body.qualification;

  res.sendStatus(204);
}

/**
 * @description delete qualification
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function deleteQualification(req: Request, res: Response): Promise<any> {
  const id = parseInt(req.params.id);

  res.sendStatus(204);
}
