import { dataSource } from "../data-source";
import { qualification } from "../entity/qualification";
import { user } from "../entity/user";
import InternalException from "../exceptions/internalException";

export default abstract class QualificationService {
  /**
   * @description get all qualifications
   * @returns {Promise<Array<qualification>>}
   */
  static async getAll(): Promise<Array<qualification>> {
    return await dataSource
      .getRepository(qualification)
      .createQueryBuilder("qualification")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch(() => {
        throw new InternalException("qualifications not found");
      });
  }

  /**
   * @description get qualification by id
   * @returns {Promise<qualification>}
   */
  static async getById(id: number): Promise<qualification> {
    return await dataSource
      .getRepository(qualification)
      .createQueryBuilder("qualification")
      .andWhere("qualification.id = :id", { id: id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch(() => {
        throw new InternalException("qualification not found by id");
      });
  }

  // /**
  //  * @description get members assigned to qualification
  //  * @returns {Promise<Array<member>>}
  //  */
  // static async getMembersByqualificationId(id: number): Promise<Array<member>> {
  //   return await dataSource
  //     .getRepository(qualification)
  //     .createQueryBuilder("qualification")
  //     .leftJoinAndSelect("qualification.members", "members")
  //     .andWhere("qualification.id = :id", { id: id })
  //     .getOneOrFail()
  //     .then((res) => {
  //       return [];
  //     })
  //     .catch(() => {
  //       throw new InternalException("qualification assigned members not found by id");
  //     });
  // }
}
